/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.HeadFontStyle;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.mybatis.base.BaseEntity;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;

/**
 * 开户行配置表
 *
 * @author hgw
 * @date 2023-03-06 11:54:21
 */
@Data
@TableName("t_bank_set")
@EqualsAndHashCode(callSuper = true)
@Schema(description = "开户行配置表")
public class TBankSet extends BaseEntity {

	/**
	 * id
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@ExcelProperty("id")
	@Schema(description = "id")
	private String id;
	/**
	 * bankName
	 */
	@ExcelAttribute(name = "开户行", isNotEmpty = true, errorInfo = "开户行不能为空", maxLength = 100)
	@NotBlank(message = "开户行不能为空")
	@Length(max = 100, message = "开户行不能超过100个字符")
	@ExcelProperty("开户行")
	@Schema(description = "开户行")
	private String bankName;
	/**
	 * 是否删除0：正常；1：已删除
	 */
	@ExcelAttribute(name = "是否删除0：正常；1：已删除")
	@HeadFontStyle(fontHeightInPoints = 11)
	@ExcelProperty("是否删除0：正常；1：已删除")
	private String deleteFlag;

}