/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.social.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.RowIndex;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.util.Date;

/**
 * 自动化实缴记录表
 *
 * @author fxj
 * @date 2024-05-24 10:56:42
 */
@Data
public class TAutoPaymentInfoVo extends RowIndex implements Serializable {

	/**
	 * id
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@NotBlank(message = "id 不能为空")
	@Length(max = 32, message = "id 不能超过32 个字符")
	@ExcelAttribute(name = "id", isNotEmpty = true, errorInfo = "id 不能为空", maxLength = 32)
	@Schema(description = "id")
	@ExcelProperty("id")
	private String id;
	/**
	 * 数据整合：1 整合中  2已整合
	 */
	@Length(max = 1, message = "数据整合：1 整合中  2已整合 不能超过1 个字符")
	@ExcelAttribute(name = "数据整合：1 整合中  2已整合", maxLength = 1)
	@Schema(description = "数据整合：1 整合中  2已整合")
	@ExcelProperty("数据整合：1 整合中  2已整合")
	private String dataIntegrationFlag;
	/**
	 * 系统复核：0复核中1复核成功2复核失败
	 */
	@Length(max = 1, message = "系统复核：0复核中1复核成功2复核失败 不能超过1 个字符")
	@ExcelAttribute(name = "系统复核：0复核中1复核成功2复核失败", maxLength = 1)
	@Schema(description = "系统复核：0复核中1复核成功2复核失败")
	@ExcelProperty("系统复核：0复核中1复核成功2复核失败")
	private String systemReviewFlag;
	/**
	 * 重新复核状态 0 复核中 1复核成功 2复核失败
	 */
	@Length(max = 1, message = "重新复核状态 0 复核中 1复核成功 2复核失败 不能超过1 个字符")
	@ExcelAttribute(name = "重新复核状态 0 复核中 1复核成功 2复核失败", maxLength = 1)
	@Schema(description = "重新复核状态 0 复核中 1复核成功 2复核失败")
	@ExcelProperty("重新复核状态 0 复核中 1复核成功 2复核失败")
	private String repeatReviewFlag;
	/**
	 * 创建人id
	 */
	@Length(max = 32, message = "创建人id 不能超过32 个字符")
	@ExcelAttribute(name = "创建人id", maxLength = 32)
	@Schema(description = "创建人id")
	@ExcelProperty("创建人id")
	private String createBy;
	/**
	 * 创建人姓名
	 */
	@Length(max = 32, message = "创建人姓名 不能超过32 个字符")
	@ExcelAttribute(name = "创建人姓名", maxLength = 32)
	@Schema(description = "创建人姓名")
	@ExcelProperty("创建人姓名")
	private String createName;
	/**
	 * 创建时间
	 */
	@ExcelAttribute(name = "创建时间", isDate = true)
	@Schema(description = "创建时间")
	@ExcelProperty("创建时间")
	private Date createTime;
	/**
	 * 更新人id
	 */
	@Length(max = 32, message = "更新人id 不能超过32 个字符")
	@ExcelAttribute(name = "更新人id", maxLength = 32)
	@Schema(description = "更新人id")
	@ExcelProperty("更新人id")
	private String updateBy;
	/**
	 * 更新时间
	 */
	@ExcelAttribute(name = "更新时间", isDate = true)
	@Schema(description = "更新时间")
	@ExcelProperty("更新时间")
	private Date updateTime;

}
