/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.social.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ArrayUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.read.listener.ReadListener;
import com.alibaba.excel.read.metadata.holder.ReadRowHolder;
import com.alibaba.excel.util.ListUtils;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.CommonConstants;
import com.yifu.cloud.plus.v1.yifu.common.core.util.*;
import com.yifu.cloud.plus.v1.yifu.common.mybatis.base.BaseEntity;
import com.yifu.cloud.plus.v1.yifu.social.entity.SysHouseHoldInfo;
import com.yifu.cloud.plus.v1.yifu.social.entity.TDispatchInfo;
import com.yifu.cloud.plus.v1.yifu.social.entity.TProvidentFund;
import com.yifu.cloud.plus.v1.yifu.social.mapper.SysHouseHoldInfoMapper;
import com.yifu.cloud.plus.v1.yifu.social.mapper.TDispatchInfoMapper;
import com.yifu.cloud.plus.v1.yifu.social.mapper.TProvidentFundMapper;
import com.yifu.cloud.plus.v1.yifu.social.service.TProvidentFundService;
import com.yifu.cloud.plus.v1.yifu.social.vo.FundAddAndReduceVo;
import com.yifu.cloud.plus.v1.yifu.social.vo.TProvidentFundSearchVo;
import com.yifu.cloud.plus.v1.yifu.social.vo.TProvidentFundVo;
import lombok.AllArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;
/**
 * 公积金信息
 *
 * @author fxj
 * @date 2022-07-15 11:38:05
 */
@AllArgsConstructor
@Log4j2
@Service
public class TProvidentFundServiceImpl extends ServiceImpl<TProvidentFundMapper, TProvidentFund> implements TProvidentFundService {

	private final TDispatchInfoMapper dispatchInfoMapper;

	private final SysHouseHoldInfoMapper sysHouseHoldInfoMapper;

    /**
     * 公积金信息简单分页查询
     * @param tProvidentFund 公积金信息
     * @return
     */
    @Override
    public IPage<TProvidentFund> getTProvidentFundPage(Page<TProvidentFund> page, TProvidentFundSearchVo tProvidentFund){
        return baseMapper.getTProvidentFundPage(page,tProvidentFund);
    }

    /**
     * 公积金信息批量导出
     * @return
     */
    @Override
    public void listExport(HttpServletResponse response, TProvidentFundSearchVo searchVo){
        String fileName = "不良记录批量导出" + DateUtil.getThisTime() + CommonConstants.XLSX;
        //获取要导出的列表
        List<TProvidentFund> list = new ArrayList<>();
        long count = noPageCountDiy(searchVo);
        ServletOutputStream out = null;
        try {
            out = response.getOutputStream();
            response.setContentType(CommonConstants.MULTIPART_FORM_DATA);
            response.setCharacterEncoding("utf-8");
            response.setHeader(CommonConstants.CONTENT_DISPOSITION, CommonConstants.ATTACHMENT_FILENAME + URLEncoder.encode(fileName  , "UTF-8"));
            // 这里 需要指定写用哪个class去写，然后写到第一个sheet，然后文件流会自动关闭
            //EasyExcel.write(out, TEmpBadRecord.class).sheet("不良记录").doWrite(list);
            ExcelWriter  excelWriter = EasyExcel.write(out, TProvidentFund.class).build();
            int index = 0;
            if (count >  CommonConstants.ZERO_INT){
				WriteSheet writeSheet;
				ExcelUtil<TProvidentFund> util;
                for (int i = 0; i <= count; ) {
                    // 获取实际记录
                    searchVo.setLimitStart(i);
                    searchVo.setLimitEnd(CommonConstants.EXCEL_EXPORT_LIMIT);
                    list = noPageDiy(searchVo);
                    if (Common.isNotNull(list)){
                        util = new ExcelUtil<>(TProvidentFund.class);
                        for (TProvidentFund vo:list){
                            util.convertEntity(vo,null,null,null);
                        }
                    }
                    if (Common.isNotNull(list)){
                        writeSheet = EasyExcel.writerSheet("公积金信息"+index).build();
                        excelWriter.write(list,writeSheet);
                        index++;
                    }
                    i = i + CommonConstants.EXCEL_EXPORT_LIMIT;
                    if (Common.isNotNull(list)){
                        list.clear();
                    }
                }
            }else {
                WriteSheet writeSheet = EasyExcel.writerSheet("公积金信息"+index).build();
                excelWriter.write(list,writeSheet);
            }
            if (Common.isNotNull(list)){
                list.clear();
            }
            out.flush();
            excelWriter.finish();
        }catch (Exception e){
            log.error("执行异常" ,e);
        }finally {
            try {
                if (null != out) {
                    out.close();
                }
            } catch (IOException e) {
                log.error("执行异常", e);
            }
        }
    }

    @Override
    public List<TProvidentFund> noPageDiy(TProvidentFundSearchVo searchVo) {
        LambdaQueryWrapper<TProvidentFund> wrapper = buildQueryWrapper(searchVo);
        List<String> idList = Common.getList(searchVo.getIds());
        if (Common.isNotNull(idList)){
            wrapper.in(TProvidentFund::getId,idList);
        }
        if (searchVo.getLimitStart() >= 0 && searchVo.getLimitEnd() > 0){
            wrapper.last(" limit "+ searchVo.getLimitStart() +","+ searchVo.getLimitEnd());
        }
        wrapper.orderByDesc(BaseEntity::getCreateTime);
        return baseMapper.selectList(wrapper);
    }

    private  Long noPageCountDiy(TProvidentFundSearchVo searchVo) {
        LambdaQueryWrapper<TProvidentFund> wrapper = buildQueryWrapper(searchVo);
        List<String> idList = Common.getList(searchVo.getIds());
        if (Common.isNotNull(idList)){
            wrapper.in(TProvidentFund::getId,idList);
        }
        return baseMapper.selectCount(wrapper);
    }

    private LambdaQueryWrapper buildQueryWrapper(TProvidentFundSearchVo entity){
        LambdaQueryWrapper<TProvidentFund> wrapper = Wrappers.lambdaQuery();
        if (ArrayUtil.isNotEmpty(entity.getCreateTimes())) {
            wrapper.ge(TProvidentFund::getCreateTime, entity.getCreateTimes()[0])
                    .le(TProvidentFund::getCreateTime,
                            entity.getCreateTimes()[1]);
        }
        if (Common.isNotNull(entity.getCreateName())){
            wrapper.eq(TProvidentFund::getCreateName,entity.getCreateName());
        }
        return wrapper;
    }

    @Override
    public R<List<ErrorMessage>> importDiy(InputStream inputStream) {
        List<ErrorMessage> errorMessageList = new ArrayList<>();
        ExcelUtil<TProvidentFundVo> util1 = new ExcelUtil<>(TProvidentFundVo.class);
        // 写法2：
        // 匿名内部类 不用额外写一个DemoDataListener
        // 这里 需要指定读用哪个class去读，然后读取第一个sheet 文件流会自动关闭
        try {
            EasyExcel.read(inputStream, TProvidentFundVo.class, new ReadListener<TProvidentFundVo>() {
                /**
                 * 单次缓存的数据量
                 */
                public static final int BATCH_COUNT = CommonConstants.BATCH_COUNT;
                /**
                 *临时存储
                 */
                private List<TProvidentFundVo> cachedDataList = ListUtils.newArrayListWithExpectedSize(BATCH_COUNT);

                @Override
                public void invoke(TProvidentFundVo data, AnalysisContext context) {
                    ReadRowHolder readRowHolder = context.readRowHolder();
                    Integer rowIndex = readRowHolder.getRowIndex();
                    data.setRowIndex(rowIndex+1);
                    ErrorMessage errorMessage = util1.checkEntity(data, data.getRowIndex());
                    if (Common.isNotNull(errorMessage)){
                        errorMessageList.add(errorMessage);
                    }else {
                        cachedDataList.add(data);
                    }
                    if (cachedDataList.size() >= BATCH_COUNT) {
                        saveData();
                        // 存储完成清理 list
                        cachedDataList = ListUtils.newArrayListWithExpectedSize(BATCH_COUNT);
                    }
                }
                @Override
                public void doAfterAllAnalysed(AnalysisContext context) {
                    saveData();
                }

                /**
                 * 加上存储数据库
                 */
                private void saveData() {
                    log.info("{}条数据，开始存储数据库！", cachedDataList.size());
                    importTProvidentFund(cachedDataList,errorMessageList);
                    log.info("存储数据库成功！");
                }
            }).sheet().doRead();
        }catch (Exception e){
            log.error(CommonConstants.IMPORT_DATA_ANALYSIS_ERROR,e);
            return R.failed(CommonConstants.IMPORT_DATA_ANALYSIS_ERROR);
        }
        return  R.ok(errorMessageList);
    }
    private void importTProvidentFund(List<TProvidentFundVo> excelVOList, List<ErrorMessage> errorMessageList) {
        // 个性化校验逻辑
        // 执行数据插入操作 组装
        for (int i = 0; i < excelVOList.size(); i++) {
            TProvidentFundVo excel = excelVOList.get(i);
            // 数据合法情况 TODO

            // 插入
            insertExcel(excel);
            errorMessageList.add(new ErrorMessage(excel.getRowIndex(),CommonConstants.SAVE_SUCCESS));
        }
    }
    /**
     * 插入excel bad record
     */
    private void insertExcel(TProvidentFundVo excel) {
        TProvidentFund insert = new TProvidentFund();
        BeanUtil.copyProperties(excel, insert);
        this.save(insert);
    }

	/**
	 * 通过ID查询员工对应的派增派减数据
	 * @Author fxj
	 * @Date 2020-08-25
	 * @param empId
	 * @return
	 **/
	@Override
	public FundAddAndReduceVo getAddOrReduceInfoByEmpId(String empId) {
		FundAddAndReduceVo fundAddAndReduceVo = new FundAddAndReduceVo();
		TProvidentFund fund = null;
		TDispatchInfo dispatchInfoAdd = dispatchInfoMapper.selectOne(Wrappers.<TDispatchInfo>query().lambda()
				.eq(TDispatchInfo::getEmpId,empId)
				.eq(TDispatchInfo::getDeleteFlag,CommonConstants.ZERO_STRING)
				.eq(TDispatchInfo::getType,CommonConstants.ZERO_STRING)
				.isNotNull(TDispatchInfo::getFundId)
				.orderByDesc(TDispatchInfo::getCreateTime)
				.last(CommonConstants.LAST_ONE_SQL));
		if (null != dispatchInfoAdd){
			fund = baseMapper.selectById(dispatchInfoAdd.getFundId());
			initFundAddAndReduce(fundAddAndReduceVo, fund, dispatchInfoAdd);
			if (null != dispatchInfoAdd.getCreateTime()){
				fundAddAndReduceVo.setFundAddDispatchDate(LocalDateTimeUtils.formatTime(dispatchInfoAdd.getCreateTime()
						,LocalDateTimeUtils.DATE_TIME_PATTERN_DEFAULT));
			}
		}
		TDispatchInfo dispatchInfoReduce = dispatchInfoMapper.selectOne(Wrappers.<TDispatchInfo>query().lambda()
				.eq(TDispatchInfo::getEmpId,empId)
				.eq(TDispatchInfo::getDeleteFlag,CommonConstants.ZERO_STRING)
				.eq(TDispatchInfo::getType,CommonConstants.ONE_STRING)
				.isNotNull(TDispatchInfo::getFundId)
				.orderByDesc(TDispatchInfo::getCreateTime)
				.last(CommonConstants.LAST_ONE_SQL));
		if (null != dispatchInfoReduce){
			fund = baseMapper.selectById(dispatchInfoReduce.getFundId());
			initFundAddAndReduce(fundAddAndReduceVo, fund, dispatchInfoReduce);
			if (Common.isNotNull(dispatchInfoReduce.getFundReduceDate())) {
				fundAddAndReduceVo.setFundEndDate(DateUtil.formatDate(dispatchInfoReduce.getFundReduceDate()));
			}
			if (null != dispatchInfoReduce.getCreateTime()){
				fundAddAndReduceVo.setFundReduceDispatchDate(LocalDateTimeUtils.formatTime(
						dispatchInfoReduce.getCreateTime(),LocalDateTimeUtils.DATE_TIME_PATTERN_DEFAULT));
			}
		}
		return fundAddAndReduceVo;
	}

	/**
	 * 初始化社保派增派减数据
	 * @Author fxj
	 * @Date 2020-08-25
	 * @param fundAddAndReduceVo
	 * @param fund
	 * @param dispatchInfo
	 * @return
	 **/
	private void initFundAddAndReduce(FundAddAndReduceVo fundAddAndReduceVo, TProvidentFund fund, TDispatchInfo dispatchInfo) {
		SysHouseHoldInfo houseHoldInfo = null;
		if (null != fund) {
			if (null != fund.getProvidentHousehold()){
				houseHoldInfo = sysHouseHoldInfoMapper.selectById(fund.getProvidentHousehold());
			}
			// 派增派单状态处理 待提交和待审核都属于派单开始
			if (CommonConstants.ZERO_STRING.equals(dispatchInfo.getType())){
				fundAddAndReduceVo.setFundHouse(null==houseHoldInfo?"":houseHoldInfo.getName());
				fundAddAndReduceVo.setFundProvince(Common.isNotNull(fund.getFundProvince())? Integer.parseInt(fund.getFundProvince()):null);
				fundAddAndReduceVo.setFundCity(Common.isNotNull(fund.getFundCity())? Integer.parseInt(fund.getFundCity()):null);
				fundAddAndReduceVo.setFundTown(Common.isNotNull(fund.getFundTown())? Integer.parseInt(fund.getFundTown()):null);
				if (null != fund.getProvidentStart()) {
					fundAddAndReduceVo.setFundStartDate(DateUtil.formatDate(fund.getProvidentStart()));
				}
				initFundAddStatus(fundAddAndReduceVo, dispatchInfo);
				// 派减派单状态处理 待提交和待审核都属于派单开始
			}else {
				fundAddAndReduceVo.setFundHouseReduce(null==houseHoldInfo?"":houseHoldInfo.getName());
				fundAddAndReduceVo.setFundProvinceReduce(Common.isNotNull(fund.getFundProvince())? Integer.parseInt(fund.getFundProvince()):null);
				fundAddAndReduceVo.setFundCityReduce(Common.isNotNull(fund.getFundCity())? Integer.parseInt(fund.getFundCity()):null);
				fundAddAndReduceVo.setFundTownReduce(Common.isNotNull(fund.getFundTown())? Integer.parseInt(fund.getFundTown()):null);
				if (null != fund.getProvidentStart()) {
					fundAddAndReduceVo.setFundStartDate(DateUtil.formatDate(fund.getProvidentStart()));
				}
				initFundReduceStatus(fundAddAndReduceVo, dispatchInfo);
			}
		}
	}

	/**
	 * 初始化公积金派减状态
	 * @Author fxj
	 * @Date 2020-08-25
	 * @param fundAddAndReduceVo
	 * @param dispatchInfo
	 * @return
	 **/
	private void initFundReduceStatus(FundAddAndReduceVo fundAddAndReduceVo, TDispatchInfo dispatchInfo) {
		if (CommonConstants.ZERO_STRING.equals(dispatchInfo.getStatus())
				|| CommonConstants.ONE_STRING.equals(dispatchInfo.getStatus())
				|| CommonConstants.THREE_STRING.equals(dispatchInfo.getStatus())
				|| CommonConstants.TWO_STRING.equals(dispatchInfo.getStatus())) {
			fundAddAndReduceVo.setFundReduceStatus(CommonConstants.ZERO_STRING);
		}
		// 办理成功
		if (CommonConstants.ONE_STRING.equals(dispatchInfo.getFundHandleStatus())) {
			fundAddAndReduceVo.setFundReduceStatus(CommonConstants.ONE_STRING);
		}
		// 办理失败
		if (CommonConstants.TWO_STRING.equals(dispatchInfo.getFundHandleStatus())) {
			fundAddAndReduceVo.setFundReduceStatus(CommonConstants.TWO_STRING);
		}
		// 部分办理失败 TODO
	}
	/**
	 * 初始化公积金派增办理状态
	 * @Author fxj
	 * @Date 2020-08-25
	 * @param fundAddAndReduceVo
	 * @param dispatchInfo
	 * @return
	 **/
	private void initFundAddStatus(FundAddAndReduceVo fundAddAndReduceVo, TDispatchInfo dispatchInfo) {
		if (CommonConstants.ZERO_STRING.equals(dispatchInfo.getStatus())
				|| CommonConstants.ONE_STRING.equals(dispatchInfo.getStatus())
				|| CommonConstants.THREE_STRING.equals(dispatchInfo.getStatus())
				||CommonConstants.TWO_STRING.equals(dispatchInfo.getStatus())) {
			fundAddAndReduceVo.setFundAddStatus(CommonConstants.ZERO_STRING);
		}
		// 办理成功
		if (CommonConstants.ONE_STRING.equals(dispatchInfo.getFundHandleStatus())) {
			fundAddAndReduceVo.setFundAddStatus(CommonConstants.ONE_STRING);
		}
		// 办理失败
		if (CommonConstants.TWO_STRING.equals(dispatchInfo.getFundHandleStatus())) {
			fundAddAndReduceVo.setFundAddStatus(CommonConstants.TWO_STRING);
		}
	}
	
}
